'use strict';

var view = require('@codemirror/view');
var language = require('@codemirror/language');
var highlight = require('@lezer/highlight');

// VSCode Light theme color definitions
const background = '#ffffff', foreground = '#383a42', caret = '#000000', selection = '#add6ff', selectionMatch = '#a8ac94', lineHighlight = '#99999926', gutterBackground = '#ffffff', gutterForeground = '#237893', gutterActiveForeground = '#0b216f', keywordColor = '#0000ff', controlKeywordColor = '#af00db', variableColor = '#0070c1', classTypeColor = '#267f99', functionColor = '#795e26', numberColor = '#098658', operatorColor = '#383a42', regexpColor = '#af00db', stringColor = '#a31515', commentColor = '#008000', linkColor = '#4078f2', invalidColor = '#e45649';
// Define the editor theme styles for VSCode Light
const vsCodeLightTheme = view.EditorView.theme({
    '&': {
        color: foreground,
        backgroundColor: background,
        fontFamily: 'Menlo, Monaco, Consolas, "Andale Mono", "Ubuntu Mono", "Courier New", monospace',
    },
    '.cm-content': {
        caretColor: caret,
    },
    '.cm-cursor, .cm-dropCursor': {
        borderLeftColor: caret,
    },
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': {
        backgroundColor: selection,
    },
    '.cm-searchMatch': {
        backgroundColor: selectionMatch,
        outline: `1px solid ${lineHighlight}`,
    },
    '.cm-activeLine': {
        backgroundColor: lineHighlight,
    },
    '.cm-gutters': {
        backgroundColor: gutterBackground,
        color: gutterForeground,
    },
    '.cm-activeLineGutter': {
        color: gutterActiveForeground,
    },
}, { dark: false });
// Define the highlighting style for code in the VSCode Light theme
const vsCodeLightHighlightStyle = language.HighlightStyle.define([
    {
        tag: [
            highlight.tags.keyword,
            highlight.tags.operatorKeyword,
            highlight.tags.modifier,
            highlight.tags.color,
            highlight.tags.constant(highlight.tags.name),
            highlight.tags.standard(highlight.tags.name),
            highlight.tags.standard(highlight.tags.tagName),
            highlight.tags.special(highlight.tags.brace),
            highlight.tags.atom,
            highlight.tags.bool,
            highlight.tags.special(highlight.tags.variableName),
        ],
        color: keywordColor,
    },
    { tag: [highlight.tags.moduleKeyword, highlight.tags.controlKeyword], color: controlKeywordColor },
    {
        tag: [
            highlight.tags.name,
            highlight.tags.deleted,
            highlight.tags.character,
            highlight.tags.macroName,
            highlight.tags.propertyName,
            highlight.tags.variableName,
            highlight.tags.labelName,
            highlight.tags.definition(highlight.tags.name),
        ],
        color: variableColor,
    },
    { tag: highlight.tags.heading, fontWeight: 'bold', color: variableColor },
    {
        tag: [
            highlight.tags.typeName,
            highlight.tags.className,
            highlight.tags.tagName,
            highlight.tags.number,
            highlight.tags.changed,
            highlight.tags.annotation,
            highlight.tags.self,
            highlight.tags.namespace,
        ],
        color: classTypeColor,
    },
    {
        tag: [highlight.tags.function(highlight.tags.variableName), highlight.tags.function(highlight.tags.propertyName)],
        color: functionColor,
    },
    { tag: [highlight.tags.number], color: numberColor },
    {
        tag: [highlight.tags.operator, highlight.tags.punctuation, highlight.tags.separator, highlight.tags.url, highlight.tags.escape, highlight.tags.regexp],
        color: operatorColor,
    },
    { tag: [highlight.tags.regexp], color: regexpColor },
    {
        tag: [highlight.tags.special(highlight.tags.string), highlight.tags.processingInstruction, highlight.tags.string, highlight.tags.inserted],
        color: stringColor,
    },
    { tag: [highlight.tags.meta, highlight.tags.comment], color: commentColor },
    { tag: highlight.tags.link, color: linkColor, textDecoration: 'underline' },
    { tag: highlight.tags.invalid, color: invalidColor },
    { tag: highlight.tags.strong, fontWeight: 'bold' },
    { tag: highlight.tags.emphasis, fontStyle: 'italic' },
    { tag: highlight.tags.strikethrough, textDecoration: 'line-through' },
]);
// Extension to enable the VSCode Light theme (both the editor theme and the highlight style)
const vsCodeLight = [
    vsCodeLightTheme,
    language.syntaxHighlighting(vsCodeLightHighlightStyle),
];

exports.vsCodeLight = vsCodeLight;
exports.vsCodeLightHighlightStyle = vsCodeLightHighlightStyle;
exports.vsCodeLightTheme = vsCodeLightTheme;
